@@ -11,13 +11,21 @@ from aiohttp.client_exceptions import ContentTypeError
 from pyps4_2ndscreen.media_art import async_search_ps_store, ResultItem
 
 from pyremoteplay.receiver import AVReceiver
-from .const import DEFAULT_POLL_COUNT, DDP_PORTS, DEFAULT_STANDBY_DELAY, Quality
+from .const import (
+    DEFAULT_POLL_COUNT,
+    DDP_PORTS,
+    Quality,
+    Resolution,
+    StreamType,
+    FPS,
+)
 from .ddp import async_get_status, get_status, wakeup
 from .session import Session
 from .util import get_users, get_profiles, format_regist_key
 from .register import register
 from .controller import Controller
 
+
 _LOGGER = logging.getLogger(__name__)
 
 STATUS_OK = 200
@@ -25,11 +33,25 @@ STATUS_STANDBY = 620
 
 
 class RPDevice:
-    """Represents a Remote Play device."""
+    """Represents a Remote Play device/host.
 
-    def __init__(self, host, max_polls=DEFAULT_POLL_COUNT):
+    Most, if not all user interactions should be performed with this class.
+    Status must be polled manually with `get_status`.
+    Most iteractions cannot be used unless there is a valid status.
+
+    :param host: IP address of Remote Play Host
+    """
+
+    @staticmethod
+    def get_all_users(profiles: dict = None, profile_path="") -> list:
+        """Return all users that have been authenticated with OAuth."""
+        if not profiles:
+            profiles = get_profiles(profile_path)
+        return list(profiles.keys())
+
+    def __init__(self, host: str):
         self._host = host
-        self._max_polls = max_polls
+        self._max_polls = DEFAULT_POLL_COUNT
         self._host_type = None
         self._host_name = None
         self._mac_address = None
@@ -43,7 +65,7 @@ class RPDevice:
         self._session = None
         self._controller = None
 
-    def get_users(self, profiles=None, profile_path=None):
+    def get_users(self, profiles: dict = None, profile_path="") -> list[str]:
         """Return Registered Users."""
         if not self.mac_address:
             _LOGGER.error("Device ID is unknown. Status needs to be updated.")
@@ -51,8 +73,12 @@ class RPDevice:
         users = get_users(self.mac_address, profiles, profile_path)
         return users
 
-    def get_profile(self, user: str, profiles=None, profile_path=None):
-        """Return valid profile for user."""
+    def get_profile(self, user: str, profiles: dict = None, profile_path="") -> dict:
+        """Return valid profile for user.
+
+        :param profiles: dict of all user profiles. If None, profiles will be retrieved from default location. Optional.
+        :param profile_path: Path to saved profile file. Specify if profile data was not saved to the default path. Optional.
+        """
         if not profiles:
             profiles = get_profiles(profile_path)
         users = self.get_users(profiles)
@@ -61,7 +87,7 @@ class RPDevice:
             return None
         return profiles.get(user)
 
-    def get_status(self):
+    def get_status(self) -> dict:
         """Return status."""
         status = get_status(self.host)
         self.set_status(status)
@@ -97,7 +123,7 @@ class RPDevice:
             _LOGGER.debug("Status: %s", self.status)
             title_id = self.status.get("running-app-titleid")
             if title_id and asyncio.get_event_loop().is_running:
-                asyncio.ensure_future(self.get_media_info(title_id))
+                asyncio.ensure_future(self._get_media_info(title_id))
             else:
                 self._media_info = None
                 self._image = None
@@ -111,22 +137,17 @@ class RPDevice:
                 and self.status.get("status-code") == STATUS_STANDBY
             ):
                 self._standby_start = time.time()
-                _LOGGER.debug(
-                    "Status changed from OK to Standby."
-                    "Disabling polls for %s seconds",
-                    DEFAULT_STANDBY_DELAY,
-                )
 
-    async def get_media_info(self, title_id, region="United States"):
+    async def _get_media_info(self, title_id: str, region="United States"):
         """Retrieve Media info."""
         result = await async_search_ps_store(title_id, region)
         self._media_info = result
         if self._media_info.cover_art:
-            await self.get_image(self.media_info.cover_art)
+            await self._get_image(self.media_info.cover_art)
         if self.callback:
             self.callback()  # pylint: disable=not-callable
 
-    async def get_image(self, url):
+    async def _get_image(self, url: str):
         """Get media image."""
         try:
             async with aiohttp.ClientSession() as session:
@@ -143,11 +164,10 @@ class RPDevice:
         profile_path="",
         receiver: AVReceiver = None,
         loop: asyncio.AbstractEventLoop = None,
-        resolution="360p",
-        fps: Union[str, int] = "low",
-        quality: Union[str, Quality] = "very_low",
-        codec="h264",
-        hdr=False,
+        resolution: Union[Resolution, str, int] = "360p",
+        fps: Union[FPS, str, int] = "low",
+        quality: Union[Quality, str, int] = "very_low",
+        codec: Union[StreamType, str, int] = "h264",
         **kwargs,
     ) -> Union[Session, None]:
         """Return initialized session if session created else return None.
@@ -176,7 +196,6 @@ class RPDevice:
             fps,
             quality,
             codec,
-            hdr,
             **kwargs,
         )
         self.controller = Controller(self.session)
@@ -193,18 +212,20 @@ class RPDevice:
         return await self.session.start()
 
     def disconnect(self):
-        """Disconnect and stop session."""
+        """Disconnect and stop session. This also sets session to None."""
         if self.session:
             if self.connected:
                 self.session.stop()
             del self._session
         self._session = None
 
-    async def standby(self, user="", profiles=None, profile_path=None) -> bool:
+    async def standby(self, user="", profiles: dict = None, profile_path="") -> bool:
         """Place Device in standby. Return True if successful.
 
         If there is a valid and connected session, no arguments need to be passed.
         Otherwise creates and connects a session first.
+
+        :param user: Name of user to use. Can be found with `get_users`
         """
         if not self.is_on:
             _LOGGER.error("Device is not on.")
@@ -233,7 +254,14 @@ class RPDevice:
         profile_path: str = None,
         key: str = "",
     ):
-        """Send Wakeup."""
+        """Send Wakeup.
+
+        Either one of key or user needs to be specified.
+        Key takes precedence over user.
+
+        :param user: Name of user to use. Can be found with `get_users`
+        :param key: Regist key from registering
+        """
         if not key:
             if not user:
                 raise ValueError("User must be specified")
@@ -245,8 +273,30 @@ class RPDevice:
         regist_key = format_regist_key(key)
         wakeup(self.host, regist_key, host_type=self.host_type)
 
-    def register(self, psn_id: str, pin: str, timeout: float = 2.0) -> dict:
-        """Register psn_id with device. Return register info."""
+    def register(
+        self,
+        user: str,
+        pin: str,
+        timeout: float = 2.0,
+        profiles: dict = None,
+        profile_path="",
+    ) -> dict:
+        """Register psn_id with device. Return register info.
+
+        :param user: User name. Can be found with `get_all_users`
+        :param pin: PIN for linking found on Remote Play Host
+        :param timeout: Timeout to wait for completion
+        """
+        if not profiles:
+            profiles = get_profiles(profile_path)
+        data = profiles.get(user)
+        if not data:
+            _LOGGER.error("User: %s not found", user)
+            return {}
+        psn_id = data.get("id")
+        if not psn_id:
+            _LOGGER.error("Error retrieving ID for user: %s", user)
+            return {}
         return register(self.host, psn_id, pin, timeout)
 
     @property
