@@ -41,7 +41,7 @@ from .keys import (
     SESSION_KEY_1_PS5,
 )
 from .stream import RPStream
-from .util import format_regist_key, log_bytes
+from .util import format_regist_key
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -137,7 +137,7 @@ def _get_rp_nonce(host_type: str, nonce: bytes) -> bytes:
         shift ^= key[index]
         rp_nonce[index] = shift % 256
     rp_nonce = bytes(rp_nonce)
-    log_bytes("RP Nonce", rp_nonce)
+    # log_bytes("RP Nonce", rp_nonce)
     return rp_nonce
 
 
@@ -156,14 +156,14 @@ def _get_aes_key(host_type: str, nonce: bytes, rp_key: bytes) -> bytes:
             shift ^= nonce[index]
         aes_key[index] = shift % 256
     aes_key = bytes(aes_key)
-    log_bytes("AES Key", aes_key)
+    # log_bytes("AES Key", aes_key)
     return aes_key
 
 
 def _gen_did() -> bytes:
     """Generate Device ID."""
     did = b"".join([DID_PREFIX, get_random_bytes(16), bytes(6)])
-    log_bytes("Device ID", did)
+    # log_bytes("Device ID", did)
     return did
 
 
@@ -175,12 +175,11 @@ class Session:
     :param receiver: A receiver for handling video and audio frames
     :param loop: A running asyncio event loop
     :param resolution: The resolution of video stream.
-        One of '360p', '540p', '720p', '1080p'
+        Name of or value of or `Resolution` enum
     :param fps: Frames per second for video stream.
-        One of 'low', '30' or 'high', '60'
-    :param quality: Quality of video stream. Name of member of `Quality` enum or `Quality` enum
-    :param codec: Video Codec to use. One of 'h264' or 'hevc'
-    :param hdr: If True use HDR for video. Ignored if codec is 'h264'
+        Name of or value of or `FPS` enum
+    :param quality: Quality of video stream. Name of or value of or `Quality` enum
+    :param codec: Video Codec to use. Name of or value of or `StreamType` enum
     """
 
     STATE_INIT = "init"
@@ -241,11 +240,10 @@ class Session:
         profile: dict,
         receiver: AVReceiver = None,
         loop: asyncio.AbstractEventLoop = None,
-        resolution="360p",
-        fps: Union[str, int] = "low",
-        quality: Union[str, Quality] = "very_low",
-        codec="h264",
-        hdr=False,
+        resolution: Union[Resolution, str, int] = "360p",
+        fps: Union[FPS, str, int] = "low",
+        quality: Union[Quality, str, int] = "very_low",
+        codec: Union[StreamType, str, int] = "h264",
         **kwargs,
     ):
         self._host = host
@@ -266,8 +264,6 @@ class Session:
         self._stream = None
         self._worker = None
         self._kwargs = kwargs
-        self._hdr = hdr
-        self._codec = codec
         self.max_width = self.max_height = None
         self.error = ""
         self._receiver = None
@@ -284,14 +280,10 @@ class Session:
         self.receiver_started = None
         self.stream_ready = None
 
-        if quality.upper() in Quality.__members__:
-            self.quality = quality
-        elif isinstance(quality, Quality):
-            self.quality = quality.name
-        else:
-            self.quality = Quality.DEFAULT.name
-        self.fps = FPS.preset(fps)
-        self.resolution = Resolution.preset(resolution)
+        self.quality = Quality.parse(quality)
+        self.fps = FPS.parse(fps)
+        self.resolution = Resolution.parse(resolution)
+        self._stream_type = StreamType.parse(codec)
 
         self.set_receiver(receiver)
 
@@ -372,7 +364,7 @@ class Session:
         nonce = response.headers.get("RP-Nonce")
         if nonce is not None:
             nonce = b64decode(nonce.encode())
-            log_bytes("Nonce", nonce)
+            # log_bytes("Nonce", nonce)
         return nonce
 
     def _get_session_headers(self, nonce: bytes) -> dict:
@@ -429,14 +421,14 @@ class Session:
             for char in session_id:
                 new_id.append(chr(char).encode())
             new_id = b"".join(new_id)
-            log_bytes("New Session ID", new_id)
+            # log_bytes("New Session ID", new_id)
             return new_id
 
-        log_bytes("Session RECV Data", data)
+        # log_bytes("Session RECV Data", data)
         payload = data[8:]
         if payload:
             payload = self._cipher.decrypt(payload)
-            log_bytes("Session PAYLOAD", payload)
+            # log_bytes("Session PAYLOAD", payload)
         try:
             msg_type = Session.MessageType(data[5])
             _LOGGER.debug("RECV %s", Session.MessageType(msg_type).name)
@@ -453,7 +445,7 @@ class Session:
                 _LOGGER.warning("RECV Session ID again")
                 return
             session_id = payload[2:]
-            log_bytes("Session ID", session_id)
+            # log_bytes("Session ID", session_id)
             try:
                 session_id.decode()
             except UnicodeDecodeError:
@@ -502,7 +494,7 @@ class Session:
     def send(self, data: bytes):
         """Send Data."""
         self._protocol.transport.write(data)
-        log_bytes("Session Send", data)
+        # log_bytes("Session Send", data)
 
     async def wakeup(self):
         """Wakeup Host."""
@@ -710,25 +702,19 @@ class Session:
     @property
     def video_format(self) -> str:
         """Return video format"""
-        return self._codec.lower()
+        return StreamType.preset(self.stream_type)
 
     @property
     def hdr(self) -> bool:
         """Return True if HDR."""
-        return self._hdr and "h264" not in self._codec
+        return self.stream_type == StreamType.HEVC_HDR
 
     @property
     def stream_type(self) -> StreamType:
         """Return Stream Type."""
-        _type = self.video_format.upper()
-        _type = _type.split("_")[0]  # Remove codec suffix
-        if self.hdr:
-            _type = f"{_type}_HDR"
-        try:
-            stream_type = StreamType[_type]
-        except KeyError:
-            stream_type = StreamType["H264"]
-        return stream_type
+        if self.type == TYPE_PS4:
+            return StreamType.H264
+        return self._stream_type
 
     @property
     def receiver(self) -> AVReceiver:
